<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{% block title %}FAQ{% endblock %}</title>
</head>
<body>
<h1>{% block heading %}{% endblock %}</h1>

{% block content %}
{% endblock %}
</body>
</html>