{% extends 'faq/base.html' %}
{% block title %}FAQ | Vote{% endblock %}
{% block heading %}Vote{% endblock %}
{% block content %}
    <form method="post">
        {% csrf_token %}
        {{form}}
        <input type="submit">
    </form>
{% endblock %}